#
# deceit-fishing.R, 30 Oct 22
#
# Data from:
# Designing and detecting lies by reasoning about other agents
# Lauren A. Oey, Adena Schachner, and Edward Vul


library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(3)


clean_subj=function(df)
{
# Exclusion based on attention check criterion.  From: analysis/analysis_E1.Rmd
# exclude.sampling <- raw %>%
#  filter(reportedDrawn > 10 | drawnRed > 10) %>%
#  .$subjID
exclude=subset(df, (reportedDrawn) > 10 | (drawnRed > 10))$subjID
cleaned=subset(df, !(subjID %in% exclude))
return(cleaned)
}


# Plot rate of deception for various red marble base rates
# Take mean of each subject
lie_rate=function(df, red_rate, col_str)
{
erbred=subset(df, probabilityRed == red_rate)

subj_mean=ddply(erbred, .(subjID), function(df)
					{
					ddply(df, .(drawnRed),
						 function(df)
						length(which(df$drawnRed < df$reportedDrawn))/nrow(df))
					}
		)

mean_dec=ddply(subj_mean, .(drawnRed), function(df)
					data.frame(mean=mean(df$V1), sd=sd(df$V1)))

lines(mean_dec$drawnRed, mean_dec$mean, col=col_str, lwd=2)

d_ply(mean_dec, .(drawnRed), function(df)
				lines(rep(df$drawnRed+red_rate/4, 2),
					c(df$mean-df$sd, df$mean+df$sd), col=col_str))
return(NULL)
}



# subjID,exptPart,trialNumber,roleCurrent,marblesSampled,probabilityRed,drawnRed,reportedDrawn,compLie,compUnifLie,compDetect,callBS,playerTrialScore,oppTrialScore,playerTotalScore,oppTotalScore,waitTime,responseTime,catchQuestion,catchKey,catchResponse,catchResponseTime,pseudoRound,trialTime

ered=read.csv("detecting-lies/expt1_red_raw.csv", as.is=TRUE)
eblue=read.csv("detecting-lies/expt1_blue_raw.csv", as.is=TRUE)

ered=clean_subj(ered)
ered=subset(ered, exptPart == "trial")
eblue=clean_subj(eblue)
eblue=subset(eblue, exptPart == "trial")

# Eclusion based on attention check criterion.  From: analysis/analysis_E1.Rmd
# exclude.sampling <- raw %>%
#  filter(reportedDrawn > 10 | drawnRed > 10) %>%
#  .$subjID

ebred=subset(ered, roleCurrent == "bullshitter")

smoothScatter(ebred$drawnRed, ebred$reportedDrawn,
	xaxs="i", yaxs="i",
	xlim=c(-0.1, 10.1), ylim=c(-0.1, 10.1),
	xlab="Actual red seen", ylab="Reported seen")

plot(0, type="n",
	xaxs="i", yaxs="i",
	xlim=c(-0.01, 10), ylim=c(0, 1.0),
	xlab="Actual red marbles seen", ylab="Fraction of reports that exceeded actual")

lie_rate(ebred, 0.2, pal_col[1])
lie_rate(ebred, 0.5, pal_col[2])
lie_rate(ebred, 0.8, pal_col[3])

legend("topright", legend=paste0(c(0.2, 0.5, 0.8), " red marbles"),
                        fill=pal_col, border="white", bty="n")

